# PulpDebClient::ContentInstallerPackagesApi

All URIs are relative to *http://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](ContentInstallerPackagesApi.md#create) | **POST** /pulp/api/v3/content/deb/installer_packages/ | Create an installer package
[**list**](ContentInstallerPackagesApi.md#list) | **GET** /pulp/api/v3/content/deb/installer_packages/ | List installer packages
[**read**](ContentInstallerPackagesApi.md#read) | **GET** {deb_installer_package_href} | Inspect an installer package



## create

> AsyncOperationResponse create(opts)

Create an installer package

Trigger an asynchronous task to create content,optionally create new repository version.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::ContentInstallerPackagesApi.new
opts = {
  repository: 'repository_example', # String | A URI of a repository the new content unit should be associated with.
  artifact: 'artifact_example', # String | Artifact file representing the physical content
  relative_path: 'relative_path_example', # String | Path where the artifact is located relative to distributions base_path
  file: File.new('/path/to/file'), # File | An uploaded file that may be turned into the content unit.
  upload: 'upload_example' # String | An uncommitted upload that may be turned into the content unit.
}

begin
  #Create an installer package
  result = api_instance.create(opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling ContentInstallerPackagesApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **repository** | **String**| A URI of a repository the new content unit should be associated with. | [optional] 
 **artifact** | **String**| Artifact file representing the physical content | [optional] 
 **relative_path** | **String**| Path where the artifact is located relative to distributions base_path | [optional] 
 **file** | **File**| An uploaded file that may be turned into the content unit. | [optional] 
 **upload** | **String**| An uncommitted upload that may be turned into the content unit. | [optional] 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: multipart/form-data, application/x-www-form-urlencoded
- **Accept**: application/json


## list

> PaginateddebInstallerPackageResponseList list(opts)

List installer packages

An InstallerPackage represents a '.udeb' installer package.  Associated artifacts: Exactly one '.udeb' installer package file.  Note that installer packages are currently used exclusively for verbatim publications. The APT publisher (both simple and structured mode) will not include these packages.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::ContentInstallerPackagesApi.new
opts = {
  architecture: 'architecture_example', # String | Filter results where architecture matches value
  auto_built_package: 'auto_built_package_example', # String | Filter results where auto_built_package matches value
  build_essential: true, # Boolean | Filter results where build_essential matches value  * `True` - yes * `False` - no
  built_using: 'built_using_example', # String | Filter results where built_using matches value
  essential: true, # Boolean | Filter results where essential matches value  * `True` - yes * `False` - no
  installed_size: 56, # Integer | Filter results where installed_size matches value
  limit: 56, # Integer | Number of results to return per page.
  maintainer: 'maintainer_example', # String | Filter results where maintainer matches value
  multi_arch: 'multi_arch_example', # String | Filter results where multi_arch matches value  * `no` - no * `same` - same * `foreign` - foreign * `allowed` - allowed
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: ['ordering_example'], # Array<String> | Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `pulp_type` - Pulp type * `-pulp_type` - Pulp type (descending) * `upstream_id` - Upstream id * `-upstream_id` - Upstream id (descending) * `timestamp_of_interest` - Timestamp of interest * `-timestamp_of_interest` - Timestamp of interest (descending) * `package` - Package * `-package` - Package (descending) * `source` - Source * `-source` - Source (descending) * `version` - Version * `-version` - Version (descending) * `architecture` - Architecture * `-architecture` - Architecture (descending) * `section` - Section * `-section` - Section (descending) * `priority` - Priority * `-priority` - Priority (descending) * `origin` - Origin * `-origin` - Origin (descending) * `tag` - Tag * `-tag` - Tag (descending) * `bugs` - Bugs * `-bugs` - Bugs (descending) * `essential` - Essential * `-essential` - Essential (descending) * `build_essential` - Build essential * `-build_essential` - Build essential (descending) * `installed_size` - Installed size * `-installed_size` - Installed size (descending) * `maintainer` - Maintainer * `-maintainer` - Maintainer (descending) * `original_maintainer` - Original maintainer * `-original_maintainer` - Original maintainer (descending) * `description` - Description * `-description` - Description (descending) * `description_md5` - Description md5 * `-description_md5` - Description md5 (descending) * `homepage` - Homepage * `-homepage` - Homepage (descending) * `built_using` - Built using * `-built_using` - Built using (descending) * `auto_built_package` - Auto built package * `-auto_built_package` - Auto built package (descending) * `multi_arch` - Multi arch * `-multi_arch` - Multi arch (descending) * `breaks` - Breaks * `-breaks` - Breaks (descending) * `conflicts` - Conflicts * `-conflicts` - Conflicts (descending) * `depends` - Depends * `-depends` - Depends (descending) * `recommends` - Recommends * `-recommends` - Recommends (descending) * `suggests` - Suggests * `-suggests` - Suggests (descending) * `enhances` - Enhances * `-enhances` - Enhances (descending) * `pre_depends` - Pre depends * `-pre_depends` - Pre depends (descending) * `provides` - Provides * `-provides` - Provides (descending) * `replaces` - Replaces * `-replaces` - Replaces (descending) * `relative_path` - Relative path * `-relative_path` - Relative path (descending) * `sha256` - Sha256 * `-sha256` - Sha256 (descending) * `custom_fields` - Custom fields * `-custom_fields` - Custom fields (descending) * `pk` - Pk * `-pk` - Pk (descending)
  origin: 'origin_example', # String | Filter results where origin matches value
  original_maintainer: 'original_maintainer_example', # String | Filter results where original_maintainer matches value
  orphaned_for: 3.4, # Float | Minutes Content has been orphaned for. -1 uses ORPHAN_PROTECTION_TIME.
  package: 'package_example', # String | Filter results where package matches value
  priority: 'priority_example', # String | Filter results where priority matches value
  pulp_href__in: ['pulp_href__in_example'], # Array<String> | Multiple values may be separated by commas.
  pulp_id__in: ['pulp_id__in_example'], # Array<String> | Multiple values may be separated by commas.
  q: 'q_example', # String | 
  repository_version: 'repository_version_example', # String | Repository Version referenced by HREF
  repository_version_added: 'repository_version_added_example', # String | Repository Version referenced by HREF
  repository_version_removed: 'repository_version_removed_example', # String | Repository Version referenced by HREF
  section: 'section_example', # String | Filter results where section matches value
  sha256: 'sha256_example', # String | Filter results where sha256 matches value
  source: 'source_example', # String | Filter results where source matches value
  tag: 'tag_example', # String | Filter results where tag matches value
  version: 'version_example', # String | Filter results where version matches value
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #List installer packages
  result = api_instance.list(opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling ContentInstallerPackagesApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **architecture** | **String**| Filter results where architecture matches value | [optional] 
 **auto_built_package** | **String**| Filter results where auto_built_package matches value | [optional] 
 **build_essential** | **Boolean**| Filter results where build_essential matches value  * &#x60;True&#x60; - yes * &#x60;False&#x60; - no | [optional] 
 **built_using** | **String**| Filter results where built_using matches value | [optional] 
 **essential** | **Boolean**| Filter results where essential matches value  * &#x60;True&#x60; - yes * &#x60;False&#x60; - no | [optional] 
 **installed_size** | **Integer**| Filter results where installed_size matches value | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **maintainer** | **String**| Filter results where maintainer matches value | [optional] 
 **multi_arch** | **String**| Filter results where multi_arch matches value  * &#x60;no&#x60; - no * &#x60;same&#x60; - same * &#x60;foreign&#x60; - foreign * &#x60;allowed&#x60; - allowed | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | [**Array&lt;String&gt;**](String.md)| Ordering  * &#x60;pulp_id&#x60; - Pulp id * &#x60;-pulp_id&#x60; - Pulp id (descending) * &#x60;pulp_created&#x60; - Pulp created * &#x60;-pulp_created&#x60; - Pulp created (descending) * &#x60;pulp_last_updated&#x60; - Pulp last updated * &#x60;-pulp_last_updated&#x60; - Pulp last updated (descending) * &#x60;pulp_type&#x60; - Pulp type * &#x60;-pulp_type&#x60; - Pulp type (descending) * &#x60;upstream_id&#x60; - Upstream id * &#x60;-upstream_id&#x60; - Upstream id (descending) * &#x60;timestamp_of_interest&#x60; - Timestamp of interest * &#x60;-timestamp_of_interest&#x60; - Timestamp of interest (descending) * &#x60;package&#x60; - Package * &#x60;-package&#x60; - Package (descending) * &#x60;source&#x60; - Source * &#x60;-source&#x60; - Source (descending) * &#x60;version&#x60; - Version * &#x60;-version&#x60; - Version (descending) * &#x60;architecture&#x60; - Architecture * &#x60;-architecture&#x60; - Architecture (descending) * &#x60;section&#x60; - Section * &#x60;-section&#x60; - Section (descending) * &#x60;priority&#x60; - Priority * &#x60;-priority&#x60; - Priority (descending) * &#x60;origin&#x60; - Origin * &#x60;-origin&#x60; - Origin (descending) * &#x60;tag&#x60; - Tag * &#x60;-tag&#x60; - Tag (descending) * &#x60;bugs&#x60; - Bugs * &#x60;-bugs&#x60; - Bugs (descending) * &#x60;essential&#x60; - Essential * &#x60;-essential&#x60; - Essential (descending) * &#x60;build_essential&#x60; - Build essential * &#x60;-build_essential&#x60; - Build essential (descending) * &#x60;installed_size&#x60; - Installed size * &#x60;-installed_size&#x60; - Installed size (descending) * &#x60;maintainer&#x60; - Maintainer * &#x60;-maintainer&#x60; - Maintainer (descending) * &#x60;original_maintainer&#x60; - Original maintainer * &#x60;-original_maintainer&#x60; - Original maintainer (descending) * &#x60;description&#x60; - Description * &#x60;-description&#x60; - Description (descending) * &#x60;description_md5&#x60; - Description md5 * &#x60;-description_md5&#x60; - Description md5 (descending) * &#x60;homepage&#x60; - Homepage * &#x60;-homepage&#x60; - Homepage (descending) * &#x60;built_using&#x60; - Built using * &#x60;-built_using&#x60; - Built using (descending) * &#x60;auto_built_package&#x60; - Auto built package * &#x60;-auto_built_package&#x60; - Auto built package (descending) * &#x60;multi_arch&#x60; - Multi arch * &#x60;-multi_arch&#x60; - Multi arch (descending) * &#x60;breaks&#x60; - Breaks * &#x60;-breaks&#x60; - Breaks (descending) * &#x60;conflicts&#x60; - Conflicts * &#x60;-conflicts&#x60; - Conflicts (descending) * &#x60;depends&#x60; - Depends * &#x60;-depends&#x60; - Depends (descending) * &#x60;recommends&#x60; - Recommends * &#x60;-recommends&#x60; - Recommends (descending) * &#x60;suggests&#x60; - Suggests * &#x60;-suggests&#x60; - Suggests (descending) * &#x60;enhances&#x60; - Enhances * &#x60;-enhances&#x60; - Enhances (descending) * &#x60;pre_depends&#x60; - Pre depends * &#x60;-pre_depends&#x60; - Pre depends (descending) * &#x60;provides&#x60; - Provides * &#x60;-provides&#x60; - Provides (descending) * &#x60;replaces&#x60; - Replaces * &#x60;-replaces&#x60; - Replaces (descending) * &#x60;relative_path&#x60; - Relative path * &#x60;-relative_path&#x60; - Relative path (descending) * &#x60;sha256&#x60; - Sha256 * &#x60;-sha256&#x60; - Sha256 (descending) * &#x60;custom_fields&#x60; - Custom fields * &#x60;-custom_fields&#x60; - Custom fields (descending) * &#x60;pk&#x60; - Pk * &#x60;-pk&#x60; - Pk (descending) | [optional] 
 **origin** | **String**| Filter results where origin matches value | [optional] 
 **original_maintainer** | **String**| Filter results where original_maintainer matches value | [optional] 
 **orphaned_for** | **Float**| Minutes Content has been orphaned for. -1 uses ORPHAN_PROTECTION_TIME. | [optional] 
 **package** | **String**| Filter results where package matches value | [optional] 
 **priority** | **String**| Filter results where priority matches value | [optional] 
 **pulp_href__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **pulp_id__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **q** | **String**|  | [optional] 
 **repository_version** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_added** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_removed** | **String**| Repository Version referenced by HREF | [optional] 
 **section** | **String**| Filter results where section matches value | [optional] 
 **sha256** | **String**| Filter results where sha256 matches value | [optional] 
 **source** | **String**| Filter results where source matches value | [optional] 
 **tag** | **String**| Filter results where tag matches value | [optional] 
 **version** | **String**| Filter results where version matches value | [optional] 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginateddebInstallerPackageResponseList**](PaginateddebInstallerPackageResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## read

> DebInstallerPackageResponse read(deb_installer_package_href, opts)

Inspect an installer package

An InstallerPackage represents a '.udeb' installer package.  Associated artifacts: Exactly one '.udeb' installer package file.  Note that installer packages are currently used exclusively for verbatim publications. The APT publisher (both simple and structured mode) will not include these packages.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::ContentInstallerPackagesApi.new
deb_installer_package_href = 'deb_installer_package_href_example' # String | 
opts = {
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #Inspect an installer package
  result = api_instance.read(deb_installer_package_href, opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling ContentInstallerPackagesApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_installer_package_href** | **String**|  | 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**DebInstallerPackageResponse**](DebInstallerPackageResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

