# PulpDebClient::ContentPackageIndicesApi

All URIs are relative to *http://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](ContentPackageIndicesApi.md#create) | **POST** /pulp/api/v3/content/deb/package_indices/ | Create a package index
[**list**](ContentPackageIndicesApi.md#list) | **GET** /pulp/api/v3/content/deb/package_indices/ | List PackageIndices
[**read**](ContentPackageIndicesApi.md#read) | **GET** {deb_package_index_href} | Inspect a package index



## create

> DebPackageIndexResponse create(deb_package_index)

Create a package index

A PackageIndex represents the package indices of a single component-architecture combination.  Associated artifacts: Exactly one 'Packages' file. May optionally include one or more of 'Packages.gz', 'Packages.xz', 'Release'. If included, the 'Release' file is a legacy per-component-and-architecture Release file.  Note: The verbatim publisher will republish all associated artifacts, while the APT publisher (both simple and structured mode) will generate any 'Packages' files it needs when creating the publication. It does not make use of PackageIndex content.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::ContentPackageIndicesApi.new
deb_package_index = PulpDebClient::DebPackageIndex.new # DebPackageIndex | 

begin
  #Create a package index
  result = api_instance.create(deb_package_index)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling ContentPackageIndicesApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_package_index** | [**DebPackageIndex**](DebPackageIndex.md)|  | 

### Return type

[**DebPackageIndexResponse**](DebPackageIndexResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## list

> PaginateddebPackageIndexResponseList list(opts)

List PackageIndices

A PackageIndex represents the package indices of a single component-architecture combination.  Associated artifacts: Exactly one 'Packages' file. May optionally include one or more of 'Packages.gz', 'Packages.xz', 'Release'. If included, the 'Release' file is a legacy per-component-and-architecture Release file.  Note: The verbatim publisher will republish all associated artifacts, while the APT publisher (both simple and structured mode) will generate any 'Packages' files it needs when creating the publication. It does not make use of PackageIndex content.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::ContentPackageIndicesApi.new
opts = {
  architecture: 'architecture_example', # String | Filter results where architecture matches value
  component: 'component_example', # String | Filter results where component matches value
  limit: 56, # Integer | Number of results to return per page.
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: ['ordering_example'], # Array<String> | Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `pulp_type` - Pulp type * `-pulp_type` - Pulp type (descending) * `upstream_id` - Upstream id * `-upstream_id` - Upstream id (descending) * `timestamp_of_interest` - Timestamp of interest * `-timestamp_of_interest` - Timestamp of interest (descending) * `component` - Component * `-component` - Component (descending) * `architecture` - Architecture * `-architecture` - Architecture (descending) * `relative_path` - Relative path * `-relative_path` - Relative path (descending) * `sha256` - Sha256 * `-sha256` - Sha256 (descending) * `artifact_set_sha256` - Artifact set sha256 * `-artifact_set_sha256` - Artifact set sha256 (descending) * `pk` - Pk * `-pk` - Pk (descending)
  orphaned_for: 3.4, # Float | Minutes Content has been orphaned for. -1 uses ORPHAN_PROTECTION_TIME.
  pulp_href__in: ['pulp_href__in_example'], # Array<String> | Multiple values may be separated by commas.
  pulp_id__in: ['pulp_id__in_example'], # Array<String> | Multiple values may be separated by commas.
  q: 'q_example', # String | 
  relative_path: 'relative_path_example', # String | Filter results where relative_path matches value
  repository_version: 'repository_version_example', # String | Repository Version referenced by HREF
  repository_version_added: 'repository_version_added_example', # String | Repository Version referenced by HREF
  repository_version_removed: 'repository_version_removed_example', # String | Repository Version referenced by HREF
  sha256: 'sha256_example', # String | Filter results where sha256 matches value
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #List PackageIndices
  result = api_instance.list(opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling ContentPackageIndicesApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **architecture** | **String**| Filter results where architecture matches value | [optional] 
 **component** | **String**| Filter results where component matches value | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | [**Array&lt;String&gt;**](String.md)| Ordering  * &#x60;pulp_id&#x60; - Pulp id * &#x60;-pulp_id&#x60; - Pulp id (descending) * &#x60;pulp_created&#x60; - Pulp created * &#x60;-pulp_created&#x60; - Pulp created (descending) * &#x60;pulp_last_updated&#x60; - Pulp last updated * &#x60;-pulp_last_updated&#x60; - Pulp last updated (descending) * &#x60;pulp_type&#x60; - Pulp type * &#x60;-pulp_type&#x60; - Pulp type (descending) * &#x60;upstream_id&#x60; - Upstream id * &#x60;-upstream_id&#x60; - Upstream id (descending) * &#x60;timestamp_of_interest&#x60; - Timestamp of interest * &#x60;-timestamp_of_interest&#x60; - Timestamp of interest (descending) * &#x60;component&#x60; - Component * &#x60;-component&#x60; - Component (descending) * &#x60;architecture&#x60; - Architecture * &#x60;-architecture&#x60; - Architecture (descending) * &#x60;relative_path&#x60; - Relative path * &#x60;-relative_path&#x60; - Relative path (descending) * &#x60;sha256&#x60; - Sha256 * &#x60;-sha256&#x60; - Sha256 (descending) * &#x60;artifact_set_sha256&#x60; - Artifact set sha256 * &#x60;-artifact_set_sha256&#x60; - Artifact set sha256 (descending) * &#x60;pk&#x60; - Pk * &#x60;-pk&#x60; - Pk (descending) | [optional] 
 **orphaned_for** | **Float**| Minutes Content has been orphaned for. -1 uses ORPHAN_PROTECTION_TIME. | [optional] 
 **pulp_href__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **pulp_id__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **q** | **String**|  | [optional] 
 **relative_path** | **String**| Filter results where relative_path matches value | [optional] 
 **repository_version** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_added** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_removed** | **String**| Repository Version referenced by HREF | [optional] 
 **sha256** | **String**| Filter results where sha256 matches value | [optional] 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginateddebPackageIndexResponseList**](PaginateddebPackageIndexResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## read

> DebPackageIndexResponse read(deb_package_index_href, opts)

Inspect a package index

A PackageIndex represents the package indices of a single component-architecture combination.  Associated artifacts: Exactly one 'Packages' file. May optionally include one or more of 'Packages.gz', 'Packages.xz', 'Release'. If included, the 'Release' file is a legacy per-component-and-architecture Release file.  Note: The verbatim publisher will republish all associated artifacts, while the APT publisher (both simple and structured mode) will generate any 'Packages' files it needs when creating the publication. It does not make use of PackageIndex content.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::ContentPackageIndicesApi.new
deb_package_index_href = 'deb_package_index_href_example' # String | 
opts = {
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #Inspect a package index
  result = api_instance.read(deb_package_index_href, opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling ContentPackageIndicesApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_package_index_href** | **String**|  | 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**DebPackageIndexResponse**](DebPackageIndexResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

