# PulpDebClient::ContentReleasesApi

All URIs are relative to *http://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](ContentReleasesApi.md#create) | **POST** /pulp/api/v3/content/deb/releases/ | Create a release
[**list**](ContentReleasesApi.md#list) | **GET** /pulp/api/v3/content/deb/releases/ | List releases
[**read**](ContentReleasesApi.md#read) | **GET** {deb_release_href} | Inspect a release



## create

> DebReleaseResponse create(deb_release)

Create a release

The Release contains release file fields, that are not relevant to the APT repo structure.  Associated artifacts: None; contains only metadata.  By non-structure relevant release file fields, we mean anything other than the Components and Architectures fields. These are handled by their own models and are not part of this model.  Note that the distribution field is part of this model, but is not added to any published release files. The \"distribution\" is defined as the path between 'dists/' and some 'Release' file. As such, it encodes the path to the relevant release file within the APT repository. It is often (but not always) equal to the \"codename\" or the \"suite\".

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::ContentReleasesApi.new
deb_release = PulpDebClient::DebRelease.new # DebRelease | 

begin
  #Create a release
  result = api_instance.create(deb_release)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling ContentReleasesApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_release** | [**DebRelease**](DebRelease.md)|  | 

### Return type

[**DebReleaseResponse**](DebReleaseResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## list

> PaginateddebReleaseResponseList list(opts)

List releases

The Release contains release file fields, that are not relevant to the APT repo structure.  Associated artifacts: None; contains only metadata.  By non-structure relevant release file fields, we mean anything other than the Components and Architectures fields. These are handled by their own models and are not part of this model.  Note that the distribution field is part of this model, but is not added to any published release files. The \"distribution\" is defined as the path between 'dists/' and some 'Release' file. As such, it encodes the path to the relevant release file within the APT repository. It is often (but not always) equal to the \"codename\" or the \"suite\".

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::ContentReleasesApi.new
opts = {
  codename: 'codename_example', # String | Filter results where codename matches value
  distribution: 'distribution_example', # String | Filter results where distribution matches value
  label: 'label_example', # String | Filter results where label matches value
  limit: 56, # Integer | Number of results to return per page.
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: ['ordering_example'], # Array<String> | Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `pulp_type` - Pulp type * `-pulp_type` - Pulp type (descending) * `upstream_id` - Upstream id * `-upstream_id` - Upstream id (descending) * `timestamp_of_interest` - Timestamp of interest * `-timestamp_of_interest` - Timestamp of interest (descending) * `codename` - Codename * `-codename` - Codename (descending) * `suite` - Suite * `-suite` - Suite (descending) * `distribution` - Distribution * `-distribution` - Distribution (descending) * `version` - Version * `-version` - Version (descending) * `origin` - Origin * `-origin` - Origin (descending) * `label` - Label * `-label` - Label (descending) * `description` - Description * `-description` - Description (descending) * `pk` - Pk * `-pk` - Pk (descending)
  origin: 'origin_example', # String | Filter results where origin matches value
  orphaned_for: 3.4, # Float | Minutes Content has been orphaned for. -1 uses ORPHAN_PROTECTION_TIME.
  package: 'package_example', # String |      Must be a comma-separated string: \"package_href,repository_or_repository_version_href\"     package_href: Filter results where Release contains Package     repository_or_repository_version_href: The RepositoryVersion href to filter by, or Repository         href (assume latest version)     
  pulp_href__in: ['pulp_href__in_example'], # Array<String> | Multiple values may be separated by commas.
  pulp_id__in: ['pulp_id__in_example'], # Array<String> | Multiple values may be separated by commas.
  q: 'q_example', # String | 
  repository_version: 'repository_version_example', # String | Repository Version referenced by HREF
  repository_version_added: 'repository_version_added_example', # String | Repository Version referenced by HREF
  repository_version_removed: 'repository_version_removed_example', # String | Repository Version referenced by HREF
  suite: 'suite_example', # String | Filter results where suite matches value
  version: 'version_example', # String | Filter results where version matches value
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #List releases
  result = api_instance.list(opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling ContentReleasesApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **codename** | **String**| Filter results where codename matches value | [optional] 
 **distribution** | **String**| Filter results where distribution matches value | [optional] 
 **label** | **String**| Filter results where label matches value | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | [**Array&lt;String&gt;**](String.md)| Ordering  * &#x60;pulp_id&#x60; - Pulp id * &#x60;-pulp_id&#x60; - Pulp id (descending) * &#x60;pulp_created&#x60; - Pulp created * &#x60;-pulp_created&#x60; - Pulp created (descending) * &#x60;pulp_last_updated&#x60; - Pulp last updated * &#x60;-pulp_last_updated&#x60; - Pulp last updated (descending) * &#x60;pulp_type&#x60; - Pulp type * &#x60;-pulp_type&#x60; - Pulp type (descending) * &#x60;upstream_id&#x60; - Upstream id * &#x60;-upstream_id&#x60; - Upstream id (descending) * &#x60;timestamp_of_interest&#x60; - Timestamp of interest * &#x60;-timestamp_of_interest&#x60; - Timestamp of interest (descending) * &#x60;codename&#x60; - Codename * &#x60;-codename&#x60; - Codename (descending) * &#x60;suite&#x60; - Suite * &#x60;-suite&#x60; - Suite (descending) * &#x60;distribution&#x60; - Distribution * &#x60;-distribution&#x60; - Distribution (descending) * &#x60;version&#x60; - Version * &#x60;-version&#x60; - Version (descending) * &#x60;origin&#x60; - Origin * &#x60;-origin&#x60; - Origin (descending) * &#x60;label&#x60; - Label * &#x60;-label&#x60; - Label (descending) * &#x60;description&#x60; - Description * &#x60;-description&#x60; - Description (descending) * &#x60;pk&#x60; - Pk * &#x60;-pk&#x60; - Pk (descending) | [optional] 
 **origin** | **String**| Filter results where origin matches value | [optional] 
 **orphaned_for** | **Float**| Minutes Content has been orphaned for. -1 uses ORPHAN_PROTECTION_TIME. | [optional] 
 **package** | **String**|      Must be a comma-separated string: \&quot;package_href,repository_or_repository_version_href\&quot;     package_href: Filter results where Release contains Package     repository_or_repository_version_href: The RepositoryVersion href to filter by, or Repository         href (assume latest version)      | [optional] 
 **pulp_href__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **pulp_id__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **q** | **String**|  | [optional] 
 **repository_version** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_added** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_removed** | **String**| Repository Version referenced by HREF | [optional] 
 **suite** | **String**| Filter results where suite matches value | [optional] 
 **version** | **String**| Filter results where version matches value | [optional] 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginateddebReleaseResponseList**](PaginateddebReleaseResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## read

> DebReleaseResponse read(deb_release_href, opts)

Inspect a release

The Release contains release file fields, that are not relevant to the APT repo structure.  Associated artifacts: None; contains only metadata.  By non-structure relevant release file fields, we mean anything other than the Components and Architectures fields. These are handled by their own models and are not part of this model.  Note that the distribution field is part of this model, but is not added to any published release files. The \"distribution\" is defined as the path between 'dists/' and some 'Release' file. As such, it encodes the path to the relevant release file within the APT repository. It is often (but not always) equal to the \"codename\" or the \"suite\".

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::ContentReleasesApi.new
deb_release_href = 'deb_release_href_example' # String | 
opts = {
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #Inspect a release
  result = api_instance.read(deb_release_href, opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling ContentReleasesApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_release_href** | **String**|  | 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**DebReleaseResponse**](DebReleaseResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

