# PulpDebClient::ContentSourcePackagesApi

All URIs are relative to *http://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](ContentSourcePackagesApi.md#create) | **POST** /pulp/api/v3/content/deb/source_packages/ | Create a source package
[**list**](ContentSourcePackagesApi.md#list) | **GET** /pulp/api/v3/content/deb/source_packages/ | List source packages
[**read**](ContentSourcePackagesApi.md#read) | **GET** {deb_source_package_href} | Inspect a source package



## create

> AsyncOperationResponse create(deb_source_package)

Create a source package

Trigger an asynchronous task to create content,optionally create new repository version.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::ContentSourcePackagesApi.new
deb_source_package = PulpDebClient::DebSourcePackage.new # DebSourcePackage | 

begin
  #Create a source package
  result = api_instance.create(deb_source_package)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling ContentSourcePackagesApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_source_package** | [**DebSourcePackage**](DebSourcePackage.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## list

> PaginateddebSourcePackageResponseList list(opts)

List source packages

A Debian Source Package file represents a '.dsc' file along with its associated artifacts such as orig.tar.gz, debian.tar.gz...  Associated artifacts: Exactly one '.dsc' file.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::ContentSourcePackagesApi.new
opts = {
  architecture: 'architecture_example', # String | Filter results where architecture matches value
  binary: 'binary_example', # String | Filter results where binary matches value
  build_conflicts: 'build_conflicts_example', # String | Filter results where build_conflicts matches value
  build_conflicts_arch: 'build_conflicts_arch_example', # String | Filter results where build_conflicts_arch matches value
  build_conflicts_indep: 'build_conflicts_indep_example', # String | Filter results where build_conflicts_indep matches value
  build_depends: 'build_depends_example', # String | Filter results where build_depends matches value
  build_depends_arch: 'build_depends_arch_example', # String | Filter results where build_depends_arch matches value
  build_depends_indep: 'build_depends_indep_example', # String | Filter results where build_depends_indep matches value
  dgit: 'dgit_example', # String | Filter results where dgit matches value
  format: 'format_example', # String | Filter results where format matches value
  homepage: 'homepage_example', # String | Filter results where homepage matches value
  limit: 56, # Integer | Number of results to return per page.
  maintainer: 'maintainer_example', # String | Filter results where maintainer matches value
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: ['ordering_example'], # Array<String> | Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `pulp_type` - Pulp type * `-pulp_type` - Pulp type (descending) * `upstream_id` - Upstream id * `-upstream_id` - Upstream id (descending) * `timestamp_of_interest` - Timestamp of interest * `-timestamp_of_interest` - Timestamp of interest (descending) * `relative_path` - Relative path * `-relative_path` - Relative path (descending) * `format` - Format * `-format` - Format (descending) * `source` - Source * `-source` - Source (descending) * `binary` - Binary * `-binary` - Binary (descending) * `architecture` - Architecture * `-architecture` - Architecture (descending) * `version` - Version * `-version` - Version (descending) * `maintainer` - Maintainer * `-maintainer` - Maintainer (descending) * `uploaders` - Uploaders * `-uploaders` - Uploaders (descending) * `homepage` - Homepage * `-homepage` - Homepage (descending) * `vcs_browser` - Vcs browser * `-vcs_browser` - Vcs browser (descending) * `vcs_arch` - Vcs arch * `-vcs_arch` - Vcs arch (descending) * `vcs_bzr` - Vcs bzr * `-vcs_bzr` - Vcs bzr (descending) * `vcs_cvs` - Vcs cvs * `-vcs_cvs` - Vcs cvs (descending) * `vcs_darcs` - Vcs darcs * `-vcs_darcs` - Vcs darcs (descending) * `vcs_git` - Vcs git * `-vcs_git` - Vcs git (descending) * `vcs_hg` - Vcs hg * `-vcs_hg` - Vcs hg (descending) * `vcs_mtn` - Vcs mtn * `-vcs_mtn` - Vcs mtn (descending) * `vcs_snv` - Vcs snv * `-vcs_snv` - Vcs snv (descending) * `testsuite` - Testsuite * `-testsuite` - Testsuite (descending) * `dgit` - Dgit * `-dgit` - Dgit (descending) * `standards_version` - Standards version * `-standards_version` - Standards version (descending) * `build_depends` - Build depends * `-build_depends` - Build depends (descending) * `build_depends_indep` - Build depends indep * `-build_depends_indep` - Build depends indep (descending) * `build_depends_arch` - Build depends arch * `-build_depends_arch` - Build depends arch (descending) * `build_conflicts` - Build conflicts * `-build_conflicts` - Build conflicts (descending) * `build_conflicts_indep` - Build conflicts indep * `-build_conflicts_indep` - Build conflicts indep (descending) * `build_conflicts_arch` - Build conflicts arch * `-build_conflicts_arch` - Build conflicts arch (descending) * `package_list` - Package list * `-package_list` - Package list (descending) * `pk` - Pk * `-pk` - Pk (descending)
  orphaned_for: 3.4, # Float | Minutes Content has been orphaned for. -1 uses ORPHAN_PROTECTION_TIME.
  package_list: 'package_list_example', # String | Filter results where package_list matches value
  pulp_href__in: ['pulp_href__in_example'], # Array<String> | Multiple values may be separated by commas.
  pulp_id__in: ['pulp_id__in_example'], # Array<String> | Multiple values may be separated by commas.
  q: 'q_example', # String | 
  relative_path: 'relative_path_example', # String | Filter results where relative_path matches value
  release: 'release_example', # String |      Must be a comma-separated string: \"release_href,repository_or_repository_version_href\"     release_href: Filter results where SourcePackage in Release     repository_or_repository_version_href: The RepositoryVersion href to filter by, or Repository         href (assume latest version)     
  release_component: 'release_component_example', # String |      Must be a comma-separated string: \"release_component_href,repository_or_repository_version_href\"     release_component_href: Filter results where SourcePackage in ReleaseComponent     repository_or_repository_version_href: The RepositoryVersion href to filter by, or Repository         href (assume latest version)     
  repository_version: 'repository_version_example', # String | Repository Version referenced by HREF
  repository_version_added: 'repository_version_added_example', # String | Repository Version referenced by HREF
  repository_version_removed: 'repository_version_removed_example', # String | Repository Version referenced by HREF
  source: 'source_example', # String | Filter results where source matches value
  standards_version: 'standards_version_example', # String | Filter results where standards_version matches value
  testsuite: 'testsuite_example', # String | Filter results where testsuite matches value
  uploaders: 'uploaders_example', # String | Filter results where uploaders matches value
  vcs_arch: 'vcs_arch_example', # String | Filter results where vcs_arch matches value
  vcs_browser: 'vcs_browser_example', # String | Filter results where vcs_browser matches value
  vcs_bzr: 'vcs_bzr_example', # String | Filter results where vcs_bzr matches value
  vcs_cvs: 'vcs_cvs_example', # String | Filter results where vcs_cvs matches value
  vcs_darcs: 'vcs_darcs_example', # String | Filter results where vcs_darcs matches value
  vcs_git: 'vcs_git_example', # String | Filter results where vcs_git matches value
  vcs_hg: 'vcs_hg_example', # String | Filter results where vcs_hg matches value
  vcs_mtn: 'vcs_mtn_example', # String | Filter results where vcs_mtn matches value
  vcs_snv: 'vcs_snv_example', # String | Filter results where vcs_snv matches value
  version: 'version_example', # String | Filter results where version matches value
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #List source packages
  result = api_instance.list(opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling ContentSourcePackagesApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **architecture** | **String**| Filter results where architecture matches value | [optional] 
 **binary** | **String**| Filter results where binary matches value | [optional] 
 **build_conflicts** | **String**| Filter results where build_conflicts matches value | [optional] 
 **build_conflicts_arch** | **String**| Filter results where build_conflicts_arch matches value | [optional] 
 **build_conflicts_indep** | **String**| Filter results where build_conflicts_indep matches value | [optional] 
 **build_depends** | **String**| Filter results where build_depends matches value | [optional] 
 **build_depends_arch** | **String**| Filter results where build_depends_arch matches value | [optional] 
 **build_depends_indep** | **String**| Filter results where build_depends_indep matches value | [optional] 
 **dgit** | **String**| Filter results where dgit matches value | [optional] 
 **format** | **String**| Filter results where format matches value | [optional] 
 **homepage** | **String**| Filter results where homepage matches value | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **maintainer** | **String**| Filter results where maintainer matches value | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | [**Array&lt;String&gt;**](String.md)| Ordering  * &#x60;pulp_id&#x60; - Pulp id * &#x60;-pulp_id&#x60; - Pulp id (descending) * &#x60;pulp_created&#x60; - Pulp created * &#x60;-pulp_created&#x60; - Pulp created (descending) * &#x60;pulp_last_updated&#x60; - Pulp last updated * &#x60;-pulp_last_updated&#x60; - Pulp last updated (descending) * &#x60;pulp_type&#x60; - Pulp type * &#x60;-pulp_type&#x60; - Pulp type (descending) * &#x60;upstream_id&#x60; - Upstream id * &#x60;-upstream_id&#x60; - Upstream id (descending) * &#x60;timestamp_of_interest&#x60; - Timestamp of interest * &#x60;-timestamp_of_interest&#x60; - Timestamp of interest (descending) * &#x60;relative_path&#x60; - Relative path * &#x60;-relative_path&#x60; - Relative path (descending) * &#x60;format&#x60; - Format * &#x60;-format&#x60; - Format (descending) * &#x60;source&#x60; - Source * &#x60;-source&#x60; - Source (descending) * &#x60;binary&#x60; - Binary * &#x60;-binary&#x60; - Binary (descending) * &#x60;architecture&#x60; - Architecture * &#x60;-architecture&#x60; - Architecture (descending) * &#x60;version&#x60; - Version * &#x60;-version&#x60; - Version (descending) * &#x60;maintainer&#x60; - Maintainer * &#x60;-maintainer&#x60; - Maintainer (descending) * &#x60;uploaders&#x60; - Uploaders * &#x60;-uploaders&#x60; - Uploaders (descending) * &#x60;homepage&#x60; - Homepage * &#x60;-homepage&#x60; - Homepage (descending) * &#x60;vcs_browser&#x60; - Vcs browser * &#x60;-vcs_browser&#x60; - Vcs browser (descending) * &#x60;vcs_arch&#x60; - Vcs arch * &#x60;-vcs_arch&#x60; - Vcs arch (descending) * &#x60;vcs_bzr&#x60; - Vcs bzr * &#x60;-vcs_bzr&#x60; - Vcs bzr (descending) * &#x60;vcs_cvs&#x60; - Vcs cvs * &#x60;-vcs_cvs&#x60; - Vcs cvs (descending) * &#x60;vcs_darcs&#x60; - Vcs darcs * &#x60;-vcs_darcs&#x60; - Vcs darcs (descending) * &#x60;vcs_git&#x60; - Vcs git * &#x60;-vcs_git&#x60; - Vcs git (descending) * &#x60;vcs_hg&#x60; - Vcs hg * &#x60;-vcs_hg&#x60; - Vcs hg (descending) * &#x60;vcs_mtn&#x60; - Vcs mtn * &#x60;-vcs_mtn&#x60; - Vcs mtn (descending) * &#x60;vcs_snv&#x60; - Vcs snv * &#x60;-vcs_snv&#x60; - Vcs snv (descending) * &#x60;testsuite&#x60; - Testsuite * &#x60;-testsuite&#x60; - Testsuite (descending) * &#x60;dgit&#x60; - Dgit * &#x60;-dgit&#x60; - Dgit (descending) * &#x60;standards_version&#x60; - Standards version * &#x60;-standards_version&#x60; - Standards version (descending) * &#x60;build_depends&#x60; - Build depends * &#x60;-build_depends&#x60; - Build depends (descending) * &#x60;build_depends_indep&#x60; - Build depends indep * &#x60;-build_depends_indep&#x60; - Build depends indep (descending) * &#x60;build_depends_arch&#x60; - Build depends arch * &#x60;-build_depends_arch&#x60; - Build depends arch (descending) * &#x60;build_conflicts&#x60; - Build conflicts * &#x60;-build_conflicts&#x60; - Build conflicts (descending) * &#x60;build_conflicts_indep&#x60; - Build conflicts indep * &#x60;-build_conflicts_indep&#x60; - Build conflicts indep (descending) * &#x60;build_conflicts_arch&#x60; - Build conflicts arch * &#x60;-build_conflicts_arch&#x60; - Build conflicts arch (descending) * &#x60;package_list&#x60; - Package list * &#x60;-package_list&#x60; - Package list (descending) * &#x60;pk&#x60; - Pk * &#x60;-pk&#x60; - Pk (descending) | [optional] 
 **orphaned_for** | **Float**| Minutes Content has been orphaned for. -1 uses ORPHAN_PROTECTION_TIME. | [optional] 
 **package_list** | **String**| Filter results where package_list matches value | [optional] 
 **pulp_href__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **pulp_id__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **q** | **String**|  | [optional] 
 **relative_path** | **String**| Filter results where relative_path matches value | [optional] 
 **release** | **String**|      Must be a comma-separated string: \&quot;release_href,repository_or_repository_version_href\&quot;     release_href: Filter results where SourcePackage in Release     repository_or_repository_version_href: The RepositoryVersion href to filter by, or Repository         href (assume latest version)      | [optional] 
 **release_component** | **String**|      Must be a comma-separated string: \&quot;release_component_href,repository_or_repository_version_href\&quot;     release_component_href: Filter results where SourcePackage in ReleaseComponent     repository_or_repository_version_href: The RepositoryVersion href to filter by, or Repository         href (assume latest version)      | [optional] 
 **repository_version** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_added** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_removed** | **String**| Repository Version referenced by HREF | [optional] 
 **source** | **String**| Filter results where source matches value | [optional] 
 **standards_version** | **String**| Filter results where standards_version matches value | [optional] 
 **testsuite** | **String**| Filter results where testsuite matches value | [optional] 
 **uploaders** | **String**| Filter results where uploaders matches value | [optional] 
 **vcs_arch** | **String**| Filter results where vcs_arch matches value | [optional] 
 **vcs_browser** | **String**| Filter results where vcs_browser matches value | [optional] 
 **vcs_bzr** | **String**| Filter results where vcs_bzr matches value | [optional] 
 **vcs_cvs** | **String**| Filter results where vcs_cvs matches value | [optional] 
 **vcs_darcs** | **String**| Filter results where vcs_darcs matches value | [optional] 
 **vcs_git** | **String**| Filter results where vcs_git matches value | [optional] 
 **vcs_hg** | **String**| Filter results where vcs_hg matches value | [optional] 
 **vcs_mtn** | **String**| Filter results where vcs_mtn matches value | [optional] 
 **vcs_snv** | **String**| Filter results where vcs_snv matches value | [optional] 
 **version** | **String**| Filter results where version matches value | [optional] 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginateddebSourcePackageResponseList**](PaginateddebSourcePackageResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## read

> DebSourcePackageResponse read(deb_source_package_href, opts)

Inspect a source package

A Debian Source Package file represents a '.dsc' file along with its associated artifacts such as orig.tar.gz, debian.tar.gz...  Associated artifacts: Exactly one '.dsc' file.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::ContentSourcePackagesApi.new
deb_source_package_href = 'deb_source_package_href_example' # String | 
opts = {
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #Inspect a source package
  result = api_instance.read(deb_source_package_href, opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling ContentSourcePackagesApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_source_package_href** | **String**|  | 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**DebSourcePackageResponse**](DebSourcePackageResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

