# PulpDebClient::DistributionsAptApi

All URIs are relative to *http://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](DistributionsAptApi.md#create) | **POST** /pulp/api/v3/distributions/deb/apt/ | Create an apt distribution
[**delete**](DistributionsAptApi.md#delete) | **DELETE** {deb_apt_distribution_href} | Delete an apt distribution
[**list**](DistributionsAptApi.md#list) | **GET** /pulp/api/v3/distributions/deb/apt/ | List apt distributions
[**partial_update**](DistributionsAptApi.md#partial_update) | **PATCH** {deb_apt_distribution_href} | Update an apt distribution
[**read**](DistributionsAptApi.md#read) | **GET** {deb_apt_distribution_href} | Inspect an apt distribution
[**set_label**](DistributionsAptApi.md#set_label) | **POST** {deb_apt_distribution_href}set_label/ | Set a label
[**unset_label**](DistributionsAptApi.md#unset_label) | **POST** {deb_apt_distribution_href}unset_label/ | Unset a label
[**update**](DistributionsAptApi.md#update) | **PUT** {deb_apt_distribution_href} | Update an apt distribution



## create

> AsyncOperationResponse create(deb_apt_distribution)

Create an apt distribution

Trigger an asynchronous create task

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::DistributionsAptApi.new
deb_apt_distribution = PulpDebClient::DebAptDistribution.new # DebAptDistribution | 

begin
  #Create an apt distribution
  result = api_instance.create(deb_apt_distribution)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling DistributionsAptApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_apt_distribution** | [**DebAptDistribution**](DebAptDistribution.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## delete

> AsyncOperationResponse delete(deb_apt_distribution_href)

Delete an apt distribution

Trigger an asynchronous delete task

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::DistributionsAptApi.new
deb_apt_distribution_href = 'deb_apt_distribution_href_example' # String | 

begin
  #Delete an apt distribution
  result = api_instance.delete(deb_apt_distribution_href)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling DistributionsAptApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_apt_distribution_href** | **String**|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list

> PaginateddebAptDistributionResponseList list(opts)

List apt distributions

An AptDistribution is just an AptPublication made available via the content app.  Creating an AptDistribution is a comparatively quick action. This way Pulp users may take as much time as is needed to prepare a VerbatimPublication or AptPublication, and then control the exact moment when that publication is made available.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::DistributionsAptApi.new
opts = {
  base_path: 'base_path_example', # String | Filter results where base_path matches value
  base_path__contains: 'base_path__contains_example', # String | Filter results where base_path contains value
  base_path__icontains: 'base_path__icontains_example', # String | Filter results where base_path contains value
  base_path__in: ['base_path__in_example'], # Array<String> | Filter results where base_path is in a comma-separated list of values
  limit: 56, # Integer | Number of results to return per page.
  name: 'name_example', # String | Filter results where name matches value
  name__contains: 'name__contains_example', # String | Filter results where name contains value
  name__icontains: 'name__icontains_example', # String | Filter results where name contains value
  name__iexact: 'name__iexact_example', # String | Filter results where name matches value
  name__in: ['name__in_example'], # Array<String> | Filter results where name is in a comma-separated list of values
  name__iregex: 'name__iregex_example', # String | Filter results where name matches regex value
  name__istartswith: 'name__istartswith_example', # String | Filter results where name starts with value
  name__regex: 'name__regex_example', # String | Filter results where name matches regex value
  name__startswith: 'name__startswith_example', # String | Filter results where name starts with value
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: ['ordering_example'], # Array<String> | Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `pulp_type` - Pulp type * `-pulp_type` - Pulp type (descending) * `name` - Name * `-name` - Name (descending) * `pulp_labels` - Pulp labels * `-pulp_labels` - Pulp labels (descending) * `base_path` - Base path * `-base_path` - Base path (descending) * `hidden` - Hidden * `-hidden` - Hidden (descending) * `pk` - Pk * `-pk` - Pk (descending)
  pulp_href__in: ['pulp_href__in_example'], # Array<String> | Multiple values may be separated by commas.
  pulp_id__in: ['pulp_id__in_example'], # Array<String> | Multiple values may be separated by commas.
  pulp_label_select: 'pulp_label_select_example', # String | Filter labels by search string
  q: 'q_example', # String | 
  repository: 'repository_example', # String | Filter results where repository matches value
  repository__in: ['repository__in_example'], # Array<String> | Filter results where repository is in a comma-separated list of values
  with_content: 'with_content_example', # String | Filter distributions based on the content served by them
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #List apt distributions
  result = api_instance.list(opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling DistributionsAptApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **base_path** | **String**| Filter results where base_path matches value | [optional] 
 **base_path__contains** | **String**| Filter results where base_path contains value | [optional] 
 **base_path__icontains** | **String**| Filter results where base_path contains value | [optional] 
 **base_path__in** | [**Array&lt;String&gt;**](String.md)| Filter results where base_path is in a comma-separated list of values | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **name** | **String**| Filter results where name matches value | [optional] 
 **name__contains** | **String**| Filter results where name contains value | [optional] 
 **name__icontains** | **String**| Filter results where name contains value | [optional] 
 **name__iexact** | **String**| Filter results where name matches value | [optional] 
 **name__in** | [**Array&lt;String&gt;**](String.md)| Filter results where name is in a comma-separated list of values | [optional] 
 **name__iregex** | **String**| Filter results where name matches regex value | [optional] 
 **name__istartswith** | **String**| Filter results where name starts with value | [optional] 
 **name__regex** | **String**| Filter results where name matches regex value | [optional] 
 **name__startswith** | **String**| Filter results where name starts with value | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | [**Array&lt;String&gt;**](String.md)| Ordering  * &#x60;pulp_id&#x60; - Pulp id * &#x60;-pulp_id&#x60; - Pulp id (descending) * &#x60;pulp_created&#x60; - Pulp created * &#x60;-pulp_created&#x60; - Pulp created (descending) * &#x60;pulp_last_updated&#x60; - Pulp last updated * &#x60;-pulp_last_updated&#x60; - Pulp last updated (descending) * &#x60;pulp_type&#x60; - Pulp type * &#x60;-pulp_type&#x60; - Pulp type (descending) * &#x60;name&#x60; - Name * &#x60;-name&#x60; - Name (descending) * &#x60;pulp_labels&#x60; - Pulp labels * &#x60;-pulp_labels&#x60; - Pulp labels (descending) * &#x60;base_path&#x60; - Base path * &#x60;-base_path&#x60; - Base path (descending) * &#x60;hidden&#x60; - Hidden * &#x60;-hidden&#x60; - Hidden (descending) * &#x60;pk&#x60; - Pk * &#x60;-pk&#x60; - Pk (descending) | [optional] 
 **pulp_href__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **pulp_id__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **pulp_label_select** | **String**| Filter labels by search string | [optional] 
 **q** | **String**|  | [optional] 
 **repository** | [**String**](.md)| Filter results where repository matches value | [optional] 
 **repository__in** | [**Array&lt;String&gt;**](String.md)| Filter results where repository is in a comma-separated list of values | [optional] 
 **with_content** | **String**| Filter distributions based on the content served by them | [optional] 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginateddebAptDistributionResponseList**](PaginateddebAptDistributionResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## partial_update

> AsyncOperationResponse partial_update(deb_apt_distribution_href, patcheddeb_apt_distribution)

Update an apt distribution

Trigger an asynchronous partial update task

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::DistributionsAptApi.new
deb_apt_distribution_href = 'deb_apt_distribution_href_example' # String | 
patcheddeb_apt_distribution = PulpDebClient::PatcheddebAptDistribution.new # PatcheddebAptDistribution | 

begin
  #Update an apt distribution
  result = api_instance.partial_update(deb_apt_distribution_href, patcheddeb_apt_distribution)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling DistributionsAptApi->partial_update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_apt_distribution_href** | **String**|  | 
 **patcheddeb_apt_distribution** | [**PatcheddebAptDistribution**](PatcheddebAptDistribution.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## read

> DebAptDistributionResponse read(deb_apt_distribution_href, opts)

Inspect an apt distribution

An AptDistribution is just an AptPublication made available via the content app.  Creating an AptDistribution is a comparatively quick action. This way Pulp users may take as much time as is needed to prepare a VerbatimPublication or AptPublication, and then control the exact moment when that publication is made available.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::DistributionsAptApi.new
deb_apt_distribution_href = 'deb_apt_distribution_href_example' # String | 
opts = {
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #Inspect an apt distribution
  result = api_instance.read(deb_apt_distribution_href, opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling DistributionsAptApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_apt_distribution_href** | **String**|  | 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**DebAptDistributionResponse**](DebAptDistributionResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## set_label

> SetLabelResponse set_label(deb_apt_distribution_href, set_label)

Set a label

Set a single pulp_label on the object to a specific value or null.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::DistributionsAptApi.new
deb_apt_distribution_href = 'deb_apt_distribution_href_example' # String | 
set_label = PulpDebClient::SetLabel.new # SetLabel | 

begin
  #Set a label
  result = api_instance.set_label(deb_apt_distribution_href, set_label)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling DistributionsAptApi->set_label: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_apt_distribution_href** | **String**|  | 
 **set_label** | [**SetLabel**](SetLabel.md)|  | 

### Return type

[**SetLabelResponse**](SetLabelResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## unset_label

> UnsetLabelResponse unset_label(deb_apt_distribution_href, unset_label)

Unset a label

Unset a single pulp_label on the object.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::DistributionsAptApi.new
deb_apt_distribution_href = 'deb_apt_distribution_href_example' # String | 
unset_label = PulpDebClient::UnsetLabel.new # UnsetLabel | 

begin
  #Unset a label
  result = api_instance.unset_label(deb_apt_distribution_href, unset_label)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling DistributionsAptApi->unset_label: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_apt_distribution_href** | **String**|  | 
 **unset_label** | [**UnsetLabel**](UnsetLabel.md)|  | 

### Return type

[**UnsetLabelResponse**](UnsetLabelResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## update

> AsyncOperationResponse update(deb_apt_distribution_href, deb_apt_distribution)

Update an apt distribution

Trigger an asynchronous update task

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::DistributionsAptApi.new
deb_apt_distribution_href = 'deb_apt_distribution_href_example' # String | 
deb_apt_distribution = PulpDebClient::DebAptDistribution.new # DebAptDistribution | 

begin
  #Update an apt distribution
  result = api_instance.update(deb_apt_distribution_href, deb_apt_distribution)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling DistributionsAptApi->update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_apt_distribution_href** | **String**|  | 
 **deb_apt_distribution** | [**DebAptDistribution**](DebAptDistribution.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json

