# PulpDebClient::PublicationsAptApi

All URIs are relative to *http://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](PublicationsAptApi.md#create) | **POST** /pulp/api/v3/publications/deb/apt/ | Create an apt publication
[**delete**](PublicationsAptApi.md#delete) | **DELETE** {deb_apt_publication_href} | Delete an apt publication
[**list**](PublicationsAptApi.md#list) | **GET** /pulp/api/v3/publications/deb/apt/ | List apt publications
[**read**](PublicationsAptApi.md#read) | **GET** {deb_apt_publication_href} | Inspect an apt publication



## create

> AsyncOperationResponse create(deb_apt_publication)

Create an apt publication

Trigger an asynchronous task to publish content

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::PublicationsAptApi.new
deb_apt_publication = PulpDebClient::DebAptPublication.new # DebAptPublication | 

begin
  #Create an apt publication
  result = api_instance.create(deb_apt_publication)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling PublicationsAptApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_apt_publication** | [**DebAptPublication**](DebAptPublication.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## delete

> delete(deb_apt_publication_href)

Delete an apt publication

An AptPublication is the ready to serve Pulp-internal representation of an AptRepositoryVersion.  When creating an APT publication, users must use simple or structured mode (or both). If the publication should include '.deb' packages that were manually uploaded to the relevant AptRepository, users must use 'simple=true'. Conversely, 'structured=true' is only useful for publishing content obtained via synchronization. Once a Pulp publication has been created, it can be served by creating a Pulp distribution (in a near atomic action).

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::PublicationsAptApi.new
deb_apt_publication_href = 'deb_apt_publication_href_example' # String | 

begin
  #Delete an apt publication
  api_instance.delete(deb_apt_publication_href)
rescue PulpDebClient::ApiError => e
  puts "Exception when calling PublicationsAptApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_apt_publication_href** | **String**|  | 

### Return type

nil (empty response body)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## list

> PaginateddebAptPublicationResponseList list(opts)

List apt publications

An AptPublication is the ready to serve Pulp-internal representation of an AptRepositoryVersion.  When creating an APT publication, users must use simple or structured mode (or both). If the publication should include '.deb' packages that were manually uploaded to the relevant AptRepository, users must use 'simple=true'. Conversely, 'structured=true' is only useful for publishing content obtained via synchronization. Once a Pulp publication has been created, it can be served by creating a Pulp distribution (in a near atomic action).

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::PublicationsAptApi.new
opts = {
  content: 'content_example', # String | Content Unit referenced by HREF
  content__in: 'content__in_example', # String | Content Unit referenced by HREF
  limit: 56, # Integer | Number of results to return per page.
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: ['ordering_example'], # Array<String> | Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `pulp_type` - Pulp type * `-pulp_type` - Pulp type (descending) * `complete` - Complete * `-complete` - Complete (descending) * `pass_through` - Pass through * `-pass_through` - Pass through (descending) * `pk` - Pk * `-pk` - Pk (descending)
  pulp_created: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_created matches value
  pulp_created__gt: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_created is greater than value
  pulp_created__gte: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_created is greater than or equal to value
  pulp_created__lt: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_created is less than value
  pulp_created__lte: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_created is less than or equal to value
  pulp_created__range: [DateTime.parse('2013-10-20T19:20:30+01:00')], # Array<DateTime> | Filter results where pulp_created is between two comma separated values
  pulp_href__in: ['pulp_href__in_example'], # Array<String> | Multiple values may be separated by commas.
  pulp_id__in: ['pulp_id__in_example'], # Array<String> | Multiple values may be separated by commas.
  q: 'q_example', # String | 
  repository: 'repository_example', # String | Repository referenced by HREF
  repository_version: 'repository_version_example', # String | Repository Version referenced by HREF
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #List apt publications
  result = api_instance.list(opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling PublicationsAptApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **content** | **String**| Content Unit referenced by HREF | [optional] 
 **content__in** | **String**| Content Unit referenced by HREF | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | [**Array&lt;String&gt;**](String.md)| Ordering  * &#x60;pulp_id&#x60; - Pulp id * &#x60;-pulp_id&#x60; - Pulp id (descending) * &#x60;pulp_created&#x60; - Pulp created * &#x60;-pulp_created&#x60; - Pulp created (descending) * &#x60;pulp_last_updated&#x60; - Pulp last updated * &#x60;-pulp_last_updated&#x60; - Pulp last updated (descending) * &#x60;pulp_type&#x60; - Pulp type * &#x60;-pulp_type&#x60; - Pulp type (descending) * &#x60;complete&#x60; - Complete * &#x60;-complete&#x60; - Complete (descending) * &#x60;pass_through&#x60; - Pass through * &#x60;-pass_through&#x60; - Pass through (descending) * &#x60;pk&#x60; - Pk * &#x60;-pk&#x60; - Pk (descending) | [optional] 
 **pulp_created** | **DateTime**| Filter results where pulp_created matches value | [optional] 
 **pulp_created__gt** | **DateTime**| Filter results where pulp_created is greater than value | [optional] 
 **pulp_created__gte** | **DateTime**| Filter results where pulp_created is greater than or equal to value | [optional] 
 **pulp_created__lt** | **DateTime**| Filter results where pulp_created is less than value | [optional] 
 **pulp_created__lte** | **DateTime**| Filter results where pulp_created is less than or equal to value | [optional] 
 **pulp_created__range** | [**Array&lt;DateTime&gt;**](DateTime.md)| Filter results where pulp_created is between two comma separated values | [optional] 
 **pulp_href__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **pulp_id__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **q** | **String**|  | [optional] 
 **repository** | **String**| Repository referenced by HREF | [optional] 
 **repository_version** | [**String**](.md)| Repository Version referenced by HREF | [optional] 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginateddebAptPublicationResponseList**](PaginateddebAptPublicationResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## read

> DebAptPublicationResponse read(deb_apt_publication_href, opts)

Inspect an apt publication

An AptPublication is the ready to serve Pulp-internal representation of an AptRepositoryVersion.  When creating an APT publication, users must use simple or structured mode (or both). If the publication should include '.deb' packages that were manually uploaded to the relevant AptRepository, users must use 'simple=true'. Conversely, 'structured=true' is only useful for publishing content obtained via synchronization. Once a Pulp publication has been created, it can be served by creating a Pulp distribution (in a near atomic action).

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::PublicationsAptApi.new
deb_apt_publication_href = 'deb_apt_publication_href_example' # String | 
opts = {
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #Inspect an apt publication
  result = api_instance.read(deb_apt_publication_href, opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling PublicationsAptApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_apt_publication_href** | **String**|  | 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**DebAptPublicationResponse**](DebAptPublicationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

