# PulpDebClient::RemotesAptApi

All URIs are relative to *http://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](RemotesAptApi.md#create) | **POST** /pulp/api/v3/remotes/deb/apt/ | Create an apt remote
[**delete**](RemotesAptApi.md#delete) | **DELETE** {deb_apt_remote_href} | Delete an apt remote
[**list**](RemotesAptApi.md#list) | **GET** /pulp/api/v3/remotes/deb/apt/ | List apt remotes
[**partial_update**](RemotesAptApi.md#partial_update) | **PATCH** {deb_apt_remote_href} | Update an apt remote
[**read**](RemotesAptApi.md#read) | **GET** {deb_apt_remote_href} | Inspect an apt remote
[**set_label**](RemotesAptApi.md#set_label) | **POST** {deb_apt_remote_href}set_label/ | Set a label
[**unset_label**](RemotesAptApi.md#unset_label) | **POST** {deb_apt_remote_href}unset_label/ | Unset a label
[**update**](RemotesAptApi.md#update) | **PUT** {deb_apt_remote_href} | Update an apt remote



## create

> DebAptRemoteResponse create(deb_apt_remote)

Create an apt remote

An AptRemote represents an external APT repository content source.  It contains the location of the upstream APT repository, as well as the user options that are applied when using the remote to synchronize the upstream repository to Pulp.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::RemotesAptApi.new
deb_apt_remote = PulpDebClient::DebAptRemote.new # DebAptRemote | 

begin
  #Create an apt remote
  result = api_instance.create(deb_apt_remote)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling RemotesAptApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_apt_remote** | [**DebAptRemote**](DebAptRemote.md)|  | 

### Return type

[**DebAptRemoteResponse**](DebAptRemoteResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## delete

> AsyncOperationResponse delete(deb_apt_remote_href)

Delete an apt remote

Trigger an asynchronous delete task

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::RemotesAptApi.new
deb_apt_remote_href = 'deb_apt_remote_href_example' # String | 

begin
  #Delete an apt remote
  result = api_instance.delete(deb_apt_remote_href)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling RemotesAptApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_apt_remote_href** | **String**|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list

> PaginateddebAptRemoteResponseList list(opts)

List apt remotes

An AptRemote represents an external APT repository content source.  It contains the location of the upstream APT repository, as well as the user options that are applied when using the remote to synchronize the upstream repository to Pulp.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::RemotesAptApi.new
opts = {
  limit: 56, # Integer | Number of results to return per page.
  name: 'name_example', # String | Filter results where name matches value
  name__contains: 'name__contains_example', # String | Filter results where name contains value
  name__icontains: 'name__icontains_example', # String | Filter results where name contains value
  name__iexact: 'name__iexact_example', # String | Filter results where name matches value
  name__in: ['name__in_example'], # Array<String> | Filter results where name is in a comma-separated list of values
  name__iregex: 'name__iregex_example', # String | Filter results where name matches regex value
  name__istartswith: 'name__istartswith_example', # String | Filter results where name starts with value
  name__regex: 'name__regex_example', # String | Filter results where name matches regex value
  name__startswith: 'name__startswith_example', # String | Filter results where name starts with value
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: ['ordering_example'], # Array<String> | Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `pulp_type` - Pulp type * `-pulp_type` - Pulp type (descending) * `name` - Name * `-name` - Name (descending) * `pulp_labels` - Pulp labels * `-pulp_labels` - Pulp labels (descending) * `url` - Url * `-url` - Url (descending) * `ca_cert` - Ca cert * `-ca_cert` - Ca cert (descending) * `client_cert` - Client cert * `-client_cert` - Client cert (descending) * `client_key` - Client key * `-client_key` - Client key (descending) * `tls_validation` - Tls validation * `-tls_validation` - Tls validation (descending) * `username` - Username * `-username` - Username (descending) * `password` - Password * `-password` - Password (descending) * `proxy_url` - Proxy url * `-proxy_url` - Proxy url (descending) * `proxy_username` - Proxy username * `-proxy_username` - Proxy username (descending) * `proxy_password` - Proxy password * `-proxy_password` - Proxy password (descending) * `download_concurrency` - Download concurrency * `-download_concurrency` - Download concurrency (descending) * `max_retries` - Max retries * `-max_retries` - Max retries (descending) * `policy` - Policy * `-policy` - Policy (descending) * `total_timeout` - Total timeout * `-total_timeout` - Total timeout (descending) * `connect_timeout` - Connect timeout * `-connect_timeout` - Connect timeout (descending) * `sock_connect_timeout` - Sock connect timeout * `-sock_connect_timeout` - Sock connect timeout (descending) * `sock_read_timeout` - Sock read timeout * `-sock_read_timeout` - Sock read timeout (descending) * `headers` - Headers * `-headers` - Headers (descending) * `rate_limit` - Rate limit * `-rate_limit` - Rate limit (descending) * `pk` - Pk * `-pk` - Pk (descending)
  pulp_href__in: ['pulp_href__in_example'], # Array<String> | Multiple values may be separated by commas.
  pulp_id__in: ['pulp_id__in_example'], # Array<String> | Multiple values may be separated by commas.
  pulp_label_select: 'pulp_label_select_example', # String | Filter labels by search string
  pulp_last_updated: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_last_updated matches value
  pulp_last_updated__gt: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_last_updated is greater than value
  pulp_last_updated__gte: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_last_updated is greater than or equal to value
  pulp_last_updated__lt: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_last_updated is less than value
  pulp_last_updated__lte: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_last_updated is less than or equal to value
  pulp_last_updated__range: [DateTime.parse('2013-10-20T19:20:30+01:00')], # Array<DateTime> | Filter results where pulp_last_updated is between two comma separated values
  q: 'q_example', # String | 
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #List apt remotes
  result = api_instance.list(opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling RemotesAptApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **name** | **String**| Filter results where name matches value | [optional] 
 **name__contains** | **String**| Filter results where name contains value | [optional] 
 **name__icontains** | **String**| Filter results where name contains value | [optional] 
 **name__iexact** | **String**| Filter results where name matches value | [optional] 
 **name__in** | [**Array&lt;String&gt;**](String.md)| Filter results where name is in a comma-separated list of values | [optional] 
 **name__iregex** | **String**| Filter results where name matches regex value | [optional] 
 **name__istartswith** | **String**| Filter results where name starts with value | [optional] 
 **name__regex** | **String**| Filter results where name matches regex value | [optional] 
 **name__startswith** | **String**| Filter results where name starts with value | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | [**Array&lt;String&gt;**](String.md)| Ordering  * &#x60;pulp_id&#x60; - Pulp id * &#x60;-pulp_id&#x60; - Pulp id (descending) * &#x60;pulp_created&#x60; - Pulp created * &#x60;-pulp_created&#x60; - Pulp created (descending) * &#x60;pulp_last_updated&#x60; - Pulp last updated * &#x60;-pulp_last_updated&#x60; - Pulp last updated (descending) * &#x60;pulp_type&#x60; - Pulp type * &#x60;-pulp_type&#x60; - Pulp type (descending) * &#x60;name&#x60; - Name * &#x60;-name&#x60; - Name (descending) * &#x60;pulp_labels&#x60; - Pulp labels * &#x60;-pulp_labels&#x60; - Pulp labels (descending) * &#x60;url&#x60; - Url * &#x60;-url&#x60; - Url (descending) * &#x60;ca_cert&#x60; - Ca cert * &#x60;-ca_cert&#x60; - Ca cert (descending) * &#x60;client_cert&#x60; - Client cert * &#x60;-client_cert&#x60; - Client cert (descending) * &#x60;client_key&#x60; - Client key * &#x60;-client_key&#x60; - Client key (descending) * &#x60;tls_validation&#x60; - Tls validation * &#x60;-tls_validation&#x60; - Tls validation (descending) * &#x60;username&#x60; - Username * &#x60;-username&#x60; - Username (descending) * &#x60;password&#x60; - Password * &#x60;-password&#x60; - Password (descending) * &#x60;proxy_url&#x60; - Proxy url * &#x60;-proxy_url&#x60; - Proxy url (descending) * &#x60;proxy_username&#x60; - Proxy username * &#x60;-proxy_username&#x60; - Proxy username (descending) * &#x60;proxy_password&#x60; - Proxy password * &#x60;-proxy_password&#x60; - Proxy password (descending) * &#x60;download_concurrency&#x60; - Download concurrency * &#x60;-download_concurrency&#x60; - Download concurrency (descending) * &#x60;max_retries&#x60; - Max retries * &#x60;-max_retries&#x60; - Max retries (descending) * &#x60;policy&#x60; - Policy * &#x60;-policy&#x60; - Policy (descending) * &#x60;total_timeout&#x60; - Total timeout * &#x60;-total_timeout&#x60; - Total timeout (descending) * &#x60;connect_timeout&#x60; - Connect timeout * &#x60;-connect_timeout&#x60; - Connect timeout (descending) * &#x60;sock_connect_timeout&#x60; - Sock connect timeout * &#x60;-sock_connect_timeout&#x60; - Sock connect timeout (descending) * &#x60;sock_read_timeout&#x60; - Sock read timeout * &#x60;-sock_read_timeout&#x60; - Sock read timeout (descending) * &#x60;headers&#x60; - Headers * &#x60;-headers&#x60; - Headers (descending) * &#x60;rate_limit&#x60; - Rate limit * &#x60;-rate_limit&#x60; - Rate limit (descending) * &#x60;pk&#x60; - Pk * &#x60;-pk&#x60; - Pk (descending) | [optional] 
 **pulp_href__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **pulp_id__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **pulp_label_select** | **String**| Filter labels by search string | [optional] 
 **pulp_last_updated** | **DateTime**| Filter results where pulp_last_updated matches value | [optional] 
 **pulp_last_updated__gt** | **DateTime**| Filter results where pulp_last_updated is greater than value | [optional] 
 **pulp_last_updated__gte** | **DateTime**| Filter results where pulp_last_updated is greater than or equal to value | [optional] 
 **pulp_last_updated__lt** | **DateTime**| Filter results where pulp_last_updated is less than value | [optional] 
 **pulp_last_updated__lte** | **DateTime**| Filter results where pulp_last_updated is less than or equal to value | [optional] 
 **pulp_last_updated__range** | [**Array&lt;DateTime&gt;**](DateTime.md)| Filter results where pulp_last_updated is between two comma separated values | [optional] 
 **q** | **String**|  | [optional] 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginateddebAptRemoteResponseList**](PaginateddebAptRemoteResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## partial_update

> AsyncOperationResponse partial_update(deb_apt_remote_href, patcheddeb_apt_remote)

Update an apt remote

Trigger an asynchronous partial update task

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::RemotesAptApi.new
deb_apt_remote_href = 'deb_apt_remote_href_example' # String | 
patcheddeb_apt_remote = PulpDebClient::PatcheddebAptRemote.new # PatcheddebAptRemote | 

begin
  #Update an apt remote
  result = api_instance.partial_update(deb_apt_remote_href, patcheddeb_apt_remote)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling RemotesAptApi->partial_update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_apt_remote_href** | **String**|  | 
 **patcheddeb_apt_remote** | [**PatcheddebAptRemote**](PatcheddebAptRemote.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## read

> DebAptRemoteResponse read(deb_apt_remote_href, opts)

Inspect an apt remote

An AptRemote represents an external APT repository content source.  It contains the location of the upstream APT repository, as well as the user options that are applied when using the remote to synchronize the upstream repository to Pulp.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::RemotesAptApi.new
deb_apt_remote_href = 'deb_apt_remote_href_example' # String | 
opts = {
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #Inspect an apt remote
  result = api_instance.read(deb_apt_remote_href, opts)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling RemotesAptApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_apt_remote_href** | **String**|  | 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**DebAptRemoteResponse**](DebAptRemoteResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## set_label

> SetLabelResponse set_label(deb_apt_remote_href, set_label)

Set a label

Set a single pulp_label on the object to a specific value or null.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::RemotesAptApi.new
deb_apt_remote_href = 'deb_apt_remote_href_example' # String | 
set_label = PulpDebClient::SetLabel.new # SetLabel | 

begin
  #Set a label
  result = api_instance.set_label(deb_apt_remote_href, set_label)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling RemotesAptApi->set_label: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_apt_remote_href** | **String**|  | 
 **set_label** | [**SetLabel**](SetLabel.md)|  | 

### Return type

[**SetLabelResponse**](SetLabelResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## unset_label

> UnsetLabelResponse unset_label(deb_apt_remote_href, unset_label)

Unset a label

Unset a single pulp_label on the object.

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::RemotesAptApi.new
deb_apt_remote_href = 'deb_apt_remote_href_example' # String | 
unset_label = PulpDebClient::UnsetLabel.new # UnsetLabel | 

begin
  #Unset a label
  result = api_instance.unset_label(deb_apt_remote_href, unset_label)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling RemotesAptApi->unset_label: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_apt_remote_href** | **String**|  | 
 **unset_label** | [**UnsetLabel**](UnsetLabel.md)|  | 

### Return type

[**UnsetLabelResponse**](UnsetLabelResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## update

> AsyncOperationResponse update(deb_apt_remote_href, deb_apt_remote)

Update an apt remote

Trigger an asynchronous update task

### Example

```ruby
# load the gem
require 'pulp_deb_client'
# setup authorization
PulpDebClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpDebClient::RemotesAptApi.new
deb_apt_remote_href = 'deb_apt_remote_href_example' # String | 
deb_apt_remote = PulpDebClient::DebAptRemote.new # DebAptRemote | 

begin
  #Update an apt remote
  result = api_instance.update(deb_apt_remote_href, deb_apt_remote)
  p result
rescue PulpDebClient::ApiError => e
  puts "Exception when calling RemotesAptApi->update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **deb_apt_remote_href** | **String**|  | 
 **deb_apt_remote** | [**DebAptRemote**](DebAptRemote.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json

